@@ -8,6 +8,8 @@ import pkg_resources
 import six
 
 from .download import download
+from .download_folder import download_folder
+from .download_folder import MAX_NUMBER_FILES
 
 distribution = pkg_resources.get_distribution("gdown")
 
@@ -57,21 +59,21 @@ def main():
         help="display version",
     )
     parser.add_argument(
-        "url_or_id", help="url or file id (with --id) to download file from"
+        "url_or_id", help="url or file/folder id (with --id) to download from"
     )
-    parser.add_argument("-O", "--output", help="output filename")
+    parser.add_argument("-O", "--output", help="output file name / path")
     parser.add_argument(
         "-q", "--quiet", action="store_true", help="suppress standard output"
     )
     parser.add_argument(
         "--fuzzy",
         action="store_true",
-        help="extract Google Drive's file ID",
+        help="(fild only) extract Google Drive's file ID",
     )
     parser.add_argument(
         "--id",
         action="store_true",
-        help="flag to specify file id instead of url",
+        help="flag to specify file/folder id instead of url",
     )
     parser.add_argument(
         "--proxy",
@@ -80,7 +82,7 @@ def main():
     parser.add_argument(
         "--speed",
         type=file_size,
-        help="download speed limit in second (e.g., '10MB' -> 10MB/s).",
+        help="download speed limit in second (e.g., '10MB' -> 10MB/s)",
     )
     parser.add_argument(
         "--no-cookies",
@@ -97,7 +99,19 @@ def main():
         "-c",
         dest="continue_",
         action="store_true",
-        help="resume getting a partially-downloaded file",
+        help="(file only) resume getting a partially-downloaded file",
+    )
+    parser.add_argument(
+        "--folder",
+        action="store_true",
+        help="download entire folder instead of a single file "
+        "(max {max} files per folder)".format(max=MAX_NUMBER_FILES),
+    )
+    parser.add_argument(
+        "--remaining-ok",
+        action="store_true",
+        help="(folder only) asserts that is ok to download max "
+        "{max} files per folder.".format(max=MAX_NUMBER_FILES),
     )
 
     args = parser.parse_args()
@@ -115,20 +129,34 @@ def main():
         url = args.url_or_id
         id = None
 
-    filename = download(
-        url=url,
-        output=args.output,
-        quiet=args.quiet,
-        proxy=args.proxy,
-        speed=args.speed,
-        use_cookies=not args.no_cookies,
-        verify=not args.no_check_certificate,
-        id=id,
-        fuzzy=args.fuzzy,
-        resume=args.continue_,
-    )
+    if args.folder:
+        filenames = download_folder(
+            url=url,
+            id=id,
+            output=args.output,
+            quiet=args.quiet,
+            proxy=args.proxy,
+            speed=args.speed,
+            use_cookies=not args.no_cookies,
+            remaining_ok=args.remaining_ok,
+        )
+        success = filenames is not None
+    else:
+        filename = download(
+            url=url,
+            output=args.output,
+            quiet=args.quiet,
+            proxy=args.proxy,
+            speed=args.speed,
+            use_cookies=not args.no_cookies,
+            verify=not args.no_check_certificate,
+            id=id,
+            fuzzy=args.fuzzy,
+            resume=args.continue_,
+        )
+        success = filename is not None
 
-    if filename is None:
+    if not success:
         sys.exit(1)
 
 
